@@ -8,6 +8,11 @@ Copyright (c) 2011 Multmeio [design+tecnologia]. All rights reserved.
 """
 
 from django.contrib import admin
-# from models import DynamicField
 
-# admin.site.register(DynamicField)
+from .models import *
+
+for Model in [DynamicFieldGroup, ContentPane, DynamicField]:
+    try:
+        admin.site.register(Model)
+    except: 
+        pass
